==> ejc-cfs-api-3.0.0-20240423.103634-210-sources.jar: com/ejianc/foundation/cfs/hystrix/CustomTableHystrix.java <==
package com.ejianc.foundation.cfs.hystrix;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.foundation.cfs.vo.ColumnVO;
import com.ejianc.foundation.cfs.vo.PageData;

import java.util.List;

import org.springframework.stereotype.Component;

import com.ejianc.foundation.cfs.api.ICustomTableApi;
import com.ejianc.framework.core.response.CommonResponse;

@Component
public class CustomTableHystrix implements ICustomTableApi {

	@Override
	public CommonResponse<String> parse(PageData pageData) {
		return CommonResponse.error("网络问题，查询失败。");
	}

	@Override
	public CommonResponse<List<ColumnVO>> queryColumnList(String appCode, String range) {
		return CommonResponse.error("网络问题，查询失败。");
	}

	@Override
	public CommonResponse<Boolean> updateBillState(String appCode, Long id, Integer billState) {
		return CommonResponse.error("网络问题，更新失败。");
	}

	/**
	 * @param appCode
	 * @param id
	 * @Author mrsir_wxp
	 * @Date 2020/12/16 查询应用单据详情
	 * @Description updateBillState
	 * @Param [appCode, id, billState]
	 * @Return com.ejianc.framework.core.response.CommonResponse<java.util.List < com.ejianc.foundation.cfs.vo.ColumnVO>>
	 */
	@Override
	public CommonResponse<JSONObject> queryDetail(String appCode, Long id) {
		return CommonResponse.error("网络问题，查询失败。");
	}

	/**
	 * @param appCode
	 * @param id
	 * @Author mrsir_wxp
	 * @Date 2020/12/16 查询应用单据 打印详情
	 * @Description updateBillState
	 * @Param [appCode, id, billState]
	 * @Return com.ejianc.framework.core.response.CommonResponse<java.util.List < com.ejianc.foundation.cfs.vo.ColumnVO>>
	 */
	@Override
	public CommonResponse<JSONObject> queryPrintDetail(String appCode, Long id) {
		return CommonResponse.error("网络问题，查询失败。");
	}

}

==> ejc-cfs-api-3.0.0-20251113.100626-233-sources.jar: com/ejianc/foundation/cfs/hystrix/CustomTableHystrix.java <==
package com.ejianc.foundation.cfs.hystrix;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.foundation.cfs.vo.ColumnVO;
import com.ejianc.foundation.cfs.vo.CustomListVO;
import com.ejianc.foundation.cfs.vo.PageData;

import java.util.List;

import org.springframework.stereotype.Component;

import com.ejianc.foundation.cfs.api.ICustomTableApi;
import com.ejianc.framework.core.response.CommonResponse;

@Component
public class CustomTableHystrix implements ICustomTableApi {

	@Override
	public CommonResponse<String> parse(PageData pageData) {
		return CommonResponse.error("网络问题，查询失败。");
	}

	@Override
	public CommonResponse<List<ColumnVO>> queryColumnList(String appCode, String range) {
		return CommonResponse.error("网络问题，查询失败。");
	}

	@Override
	public CommonResponse<Boolean> updateBillState(String appCode, Long id, Integer billState) {
		return CommonResponse.error("网络问题，更新失败。");
	}

	/**
	 * @param appCode
	 * @param id
	 * @Author mrsir_wxp
	 * @Date 2020/12/16 查询应用单据详情
	 * @Description updateBillState
	 * @Param [appCode, id, billState]
	 * @Return com.ejianc.framework.core.response.CommonResponse<java.util.List < com.ejianc.foundation.cfs.vo.ColumnVO>>
	 */
	@Override
	public CommonResponse<JSONObject> queryDetail(String appCode, Long id) {
		return CommonResponse.error("网络问题，查询失败。");
	}

	/**
	 * @param appCode
	 * @param id
	 * @Author mrsir_wxp
	 * @Date 2020/12/16 查询应用单据 打印详情
	 * @Description updateBillState
	 * @Param [appCode, id, billState]
	 * @Return com.ejianc.framework.core.response.CommonResponse<java.util.List < com.ejianc.foundation.cfs.vo.ColumnVO>>
	 */
	@Override
	public CommonResponse<JSONObject> queryPrintDetail(String appCode, Long id) {
		return CommonResponse.error("网络问题，查询失败。");
	}

	/**
	 * @param appCode
	 * @Author mrsir_wxp
	 * @Date 2025/7/22 查询应用的审批显示字段
	 * @Description queryColumsForBpm
	 * @Param [appCode, id, billState]
	 * @Return com.ejianc.framework.core.response.CommonResponse<java.util.List < com.ejianc.foundation.cfs.vo.CustomListVO>>
	 */
	@Override
	public CommonResponse<List<CustomListVO>> queryColumnsForBpm(String appCode) {
		return CommonResponse.error("网络问题，查询失败。");
	}

}
